@@ -11,7 +11,7 @@ BrowserID protocol:
 """
 
 __ver_major__ = 0
-__ver_minor__ = 4
+__ver_minor__ = 5
 __ver_patch__ = 0
 __ver_sub__ = ""
 __ver_tuple__ = (__ver_major__, __ver_minor__, __ver_patch__, __ver_sub__)
@@ -401,7 +401,7 @@ $(function() {
     // Fire up the BrowserID callback when clicked.
     //
     $("#signin").click(function() {
-        navigator.id.getVerifiedEmail(function(assertion) {
+        navigator.id.get(function(assertion) {
             if (assertion) {
                 var $form = $("<form method=POST "+
                               "      action='%(postback_url)s'>" +
