@@ -1,38 +1,6 @@
-# ***** BEGIN LICENSE BLOCK *****
-# Version: MPL 1.1/GPL 2.0/LGPL 2.1
-#
-# The contents of this file are subject to the Mozilla Public License Version
-# 1.1 (the "License"); you may not use this file except in compliance with
-# the License. You may obtain a copy of the License at
-# http://www.mozilla.org/MPL/
-#
-# Software distributed under the License is distributed on an "AS IS" basis,
-# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
-# for the specific language governing rights and limitations under the
-# License.
-#
-# The Original Code is repoze.who.plugins.browserid
-#
-# The Initial Developer of the Original Code is the Mozilla Foundation.
-# Portions created by the Initial Developer are Copyright (C) 2011
-# the Initial Developer. All Rights Reserved.
-#
-# Contributor(s):
-#   Ryan Kelly (rkelly@mozilla.com)
-#
-# Alternatively, the contents of this file may be used under the terms of
-# either the GNU General Public License Version 2 or later (the "GPL"), or
-# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
-# in which case the provisions of the GPL or the LGPL are applicable instead
-# of those above. If you wish to allow use of your version of this file only
-# under the terms of either the GPL or the LGPL, and not to allow others to
-# use your version of this file under the terms of the MPL, indicate your
-# decision by deleting the provisions above and replace them with the notice
-# and other provisions required by the GPL or the LGPL. If you do not delete
-# the provisions above, a recipient may use your version of this file under
-# the terms of any one of the MPL, the GPL or the LGPL.
-#
-# ***** END LICENSE BLOCK *****
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this file,
+# You can obtain one at http://mozilla.org/MPL/2.0/.
 
 import unittest2
 import tempfile
@@ -51,7 +19,8 @@ from repoze.who.middleware import PluggableAuthenticationMiddleware
 
 from webtest import TestApp
 
-from vep.utils import get_assertion_info
+from browserid.verifiers import Verifier
+from browserid.utils import get_assertion_info
 
 from repoze.who.plugins.browserid import (BrowserIDPlugin,
                                           make_plugin,
@@ -101,19 +70,24 @@ class DummyRememberer(object):
         return [("X-Dummy-Remember", "")]
 
 
-class DummyVerifierValid(object):
+class DummyVerifierValid(Verifier):
     """Dummy verifier class that thinks everything is valid."""
 
     def verify(self, assertion, audience=None):
         info = get_assertion_info(assertion)
+        self.check_audience(assertion, audience)
         return {"status": "okay",
                 "audience": info["audience"],
                 "email": info["principal"]["email"]}
 
 
-class DummyVerifierInvalid(object):
+class DummyVerifierInvalid(Verifier):
     """Dummy verifier class that thinks everything is invalid."""
 
+    def __init__(self, **kwds):
+        for attr in kwds:
+            setattr(self, attr, kwds[attr])
+
     def verify(self, assertion, audience=None):
         raise ValueError("Invalid BrowserID assertion")
 
@@ -193,8 +167,8 @@ class TestBrowserIDPlugin(unittest2.TestCase):
             csrf_field="for_your_protection",
             csrf_cookie_name="monster",
             challenge_body=ref("CHALLENGE_BODY"),
-            verifier="vep:RemoteVerifier",
-            verifier_urlopen="urllib2:urlopen",
+            verifier=ref("DummyVerifierInvalid"),
+            verifier_test_kwd="TESTING",
             check_https="no",
             check_referer="on")
         self.assertEquals(plugin.audiences, ["example.com"])
@@ -205,9 +179,10 @@ class TestBrowserIDPlugin(unittest2.TestCase):
         self.assertEquals(plugin.csrf_field, "for_your_protection")
         self.assertEquals(plugin.csrf_cookie_name, "monster")
         self.assertEquals(plugin.challenge_body, "CHALLENGE HO!")
-        self.assertEquals(plugin.verifier.urlopen, urllib2.urlopen)
         self.assertEquals(plugin.check_https, False)
         self.assertEquals(plugin.check_referer, True)
+        self.assertEquals(plugin.verifier.__class__, DummyVerifierInvalid)
+        self.assertEquals(plugin.verifier.test_kwd, "TESTING")
         # Test that everything gets a sensible default.
         plugin = make_plugin("siteone sitetwo")
         self.assertEquals(plugin.audiences, ["siteone", "sitetwo"])
@@ -398,7 +373,7 @@ class TestBrowserIDPlugin(unittest2.TestCase):
         userid = plugin.authenticate(environ, identity)
         self.assertEquals(userid, None)
         self.assertEquals(environ[_ENVKEY_ERROR_MESSAGE],
-                          "The audience \"BAD\" is not recognised")
+                          "Invalid BrowserID assertion")
 
     def test_auth_with_unrecognised_audience(self):
         plugin = BrowserIDPlugin(["GOOD"], verifier=DummyVerifierValid())
@@ -408,7 +383,7 @@ class TestBrowserIDPlugin(unittest2.TestCase):
         userid = plugin.authenticate(environ, identity)
         self.assertEquals(userid, None)
         self.assertEquals(environ[_ENVKEY_ERROR_MESSAGE],
-                          "The audience \"BAD\" is not recognised")
+                          "Invalid BrowserID assertion")
 
     def test_auth_with_good_assertion(self):
         plugin = BrowserIDPlugin(["localhost"], verifier=DummyVerifierValid())
@@ -479,3 +454,11 @@ class TestBrowserIDPlugin(unittest2.TestCase):
         self.failUnless("POST" in r.body)
         self.failUnless(plugin.postback_url in r.body)
         self.failUnless("Secure" in r.headers['Set-Cookie'])
+
+    def test_handling_of_unicode_body(self):
+        app = TestApp(self._make_wsgi_app())
+        plugin = app.app.api_factory.identifiers[0][1]
+        plugin.challenge_body += u"/postback_\N{SNOWMAN}"
+        extra_environ = {"HTTP_HOST": "localhost", "wsgi.url_scheme": "https"}
+        r = app.get("/", status=401, extra_environ=extra_environ)
+        self.assertEquals(r.body.decode("utf8")[-1], u"\N{SNOWMAN}")
